@@ -13,10 +13,10 @@ def modelfit(algo, train, test, predictors, target, IDcol, filename):
     #Perform cross-validation:
     cv_score = cross_val_score(algo, train[predictors],(train[target]) , cv=20, scoring='neg_mean_squared_error')
     cv_score = np.sqrt(np.abs(cv_score))
-    score=algo.score(test[predictors],test[target])
+    #score=algo.score(test[predictors],train_predictions)
     #Print model report:
     print("\nModel Report")
-    print("Accuracy Score : ",score)
+    #print("Accuracy Score : ",score)
     print("RMSE : %.4g" % np.sqrt(metrics.mean_squared_error((train[target]).values, train_predictions)))
     print("CV Score : Mean - %.4g | Std - %.4g | Min - %.4g | Max - %.4g" % (np.mean(cv_score),np.std(cv_score),np.min(cv_score),np.max(cv_score)))
     
